from dg_ai_platform.dg_platform import ITaskProcess
from PIL import Image, ImageOps
from dg_ai_platform.utils import get_dynamic_outputs

class TaskProcess1toN(ITaskProcess):
    def __init__(self):
        super().__init__()

    def inference(self, input_list, output_list, options=None):
        print(options)
        img1 = Image.open(input_list[0]).convert('RGB')
        output1 = ImageOps.grayscale(img1)

        output1.save(output_list[0])
        if options is not None:
            if 'dynamic_outputs' in options:
                #If you need 4 image outputs
                d_outputs = get_dynamic_outputs(output_list, 4, ['jpg'])
                for fn in d_outputs:
                    ImageOps.posterize(img1, 1).save(fn)
                return d_outputs


import base64
import oss2, requests, json, os
from hashlib import md5

def get_b64(s):
    json_str = s.encode('utf-8')
    return base64.b64encode(json_str).decode('utf-8')

def get_b64_md5(url, json_obj, key):
    if json_obj is not None:
        json_str = json.dumps(json_obj)
    else:
        json_str = ''
    b64 = get_b64(url + json_str)
    md5_s = md5((b64 + key).encode('utf8')).hexdigest()
    if json_obj is not None:
        return get_b64(json_str), md5_s
    else:
        return '', md5_s

def get_dynamic_outputs( outputs, d_output_len, file_ext_list):
    dynamic_outputs = []
    output_len = len(outputs)
    output = outputs[output_len-1]
    dir = os.path.dirname(output)
    base_name = os.path.basename(output)
    for i in range(d_output_len):
        if i < len(file_ext_list):
            file_ext = file_ext_list[i]
        else:
            file_ext = file_ext_list[len(file_ext_list)-1]
        base_name_fixed = f"{base_name[:base_name.rfind('_')]}_{output_len+i}.{file_ext}"
        dynamic_outputs.append(os.path.join(dir, base_name_fixed))
    return dynamic_outputs



from dg_ai_platform.dg_platform import ITaskProcess
from PIL import Image, ImageOps

class TaskProcess2to2(ITaskProcess):
    def __init__(self):
        super().__init__()

    def inference(self, input_list, output_list, options=None):
        #load input
        img1 = Image.open(input_list[0]).convert('RGB')
        img2 = Image.open(input_list[1]).convert('RGB')

        # use option param
        if options is not None:
            if 'scale' in options:
                scale_v = options['scale']
                img1 = img1.resize((int(img1.width * scale_v), int(img1.height * scale_v)))
                img2 = img2.resize((int(img2.width * scale_v), int(img2.height * scale_v)))
        # process
        output1 = ImageOps.grayscale(img1)
        output2 = ImageOps.posterize(img2, 1)

        #save output
        output1.save(output_list[0])
        output2.save(output_list[1])